/*
 * @Author: SiMeiyu 
 * @Date: 2017-07-04 09:58:44 
 */ 
import classnames from 'classnames';
import './checkBox.less';

class CheckBox extends React.Component {

    static propTypes = {
        name: React.PropTypes.string.isRequired,
        onChange: React.PropTypes.func,
        onToggle: React.PropTypes.func,
        defaultChecked: React.PropTypes.bool,
        disabled: React.PropTypes.bool,
        inline: React.PropTypes.bool,
        title: React.PropTypes.oneOfType([
            React.PropTypes.string,
            React.PropTypes.node,
            React.PropTypes.element,
        ]),
        prefixCls: React.PropTypes.string,
        className: React.PropTypes.string,
        btnStyle: React.PropTypes.bool,
    };

    static defaultProps = {
        inline: false,
        disabled: false,
        defaultChecked: false,
        prefixCls: "ult",
    }

    constructor(props) {
        super(props);
        this.state = {
            checked: 'checked' in this.props ? this.props.checked : this.props.defaultChecked,
        }
    }

    componentWillReceiveProps(nextProps) {
        if ("checked" in nextProps || "defaultChecked" in nextProps) {
            this.setState({
                checked: nextProps.checked || nextProps.defaultChecked,
            })
        }
    }

    handleChange(e) {
        const {onToggle, onChange, disabled } = this.props;
        if (disabled) {
            return;
        }
        const checked = e.target.checked;
        this.setState({
            checked,
        })
        if (onChange) {
            const value = e.currentTarget.value;
            onChange(value);
        }
        if (onToggle) {
            onToggle(checked)
        }     
    }

    render() {
        const {className, title, name, value, defaultChecked, disabled, prefixCls, inline, btnStyle } = this.props;
        const { checked } = this.state;
        const classes = classnames(`${prefixCls}-checkbox`, className, {[`${prefixCls}-checkbox-inline`]: inline, "checked": checked, "disabled": disabled});
        if (btnStyle) {
            return (
                <label className={classnames(`${prefixCls}-btn`, {"checked": checked, "disabled": disabled})}>
                    <input type="checkbox" checked={checked} name={name} value={value || title} onChange={this.handleChange.bind(this)} disabled={disabled} />
                    {title}
                </label>
            )
        }
        return (
            <label className={classes}>
                <span className={`${prefixCls}-checkbox-inner ${prefixCls}-checkbox-type`} ></span>
                <input type="checkbox" checked={checked} name={name} value={value || title} onChange={this.handleChange.bind(this)} disabled={disabled} />
                {title}
            </label>
        )
    }
}

export default CheckBox