/*
 * @Author: SiMeiyu 
 * @Date: 2017-07-04 09:59:05 
 */ 
import classnames from 'classnames';
import CheckBox from './checkBox';
import './checkBox.less';

function handleChecked(checkedItems, item) {
  if (checkedItems.length) {
    let targIndex = checkedItems.findIndex((value, index, arr) => value === item);
    return targIndex > -1;
  }
}

class CheckboxGroup extends React.Component {
  
  static propTypes = {
    items: React.PropTypes.array.isRequired,
    className: React.PropTypes.string,
    defaultValue: React.PropTypes.array,
    // value: React.PropTypes.array,
    prefixCls: React.PropTypes.string,
    onChange: React.PropTypes.func,
    type: React.PropTypes.oneOf(['button', 'normal']),
  }

  static defaultProps = {
    name: 'radioGroup',
    prefixCls: "ult",
  }

  constructor(props) {
    super(props);
    this.state = {
      checkedItems: this.props.defaultValue || [], 
    }
  }

  componentWillReceiveProps(nextProps) {
    if ("defaultValue" in nextProps) {
      this.setState({
          checkedItems: nextProps.defaultValue,
      });
    }
  } 

  handleChange(value) {
    let values = this.state.checkedItems;
    let decide = handleChecked(values, value);
    let newValue = [];
    if (decide) {
      newValue = values.filter((item) => item != value)
    } else {
      newValue = values.concat(value);
    }

    this.setState({
      checkedItems: newValue,
    });

    if(this.props.onChange) {
      this.props.onChange(newValue);
    }
  }

  render() {
    const {className, prefixCls, name, items, inline, btnStyle} = this.props;
    const classes = classnames({
      [`${prefixCls}-checkbox-group`]: !btnStyle,
      [`${prefixCls}-btn-group`]: btnStyle && inline,
      [`${prefixCls}-btn-group-vertical`]: btnStyle && !inline,
    }, className);
    
    return (
      <div className={classes}>
        {
          items.map((item, index) => (
            <CheckBox
              key={index}
              name={name}
              value={item.value}
              title={item.title}
              disabled={item.disabled || false}
              checked={handleChecked(this.state.checkedItems, item.value) || false}
              onChange={this.handleChange.bind(this)}
              inline={inline || false}
              btnStyle={btnStyle}
            />
          ))
        }
      </div>
    )
  }
}

export default CheckboxGroup;