/*
 * @Author: SiMeiyu 
 * @Date: 2017-07-04 09:59:16 
 */ 
import classnames from 'classnames';
import './checkBox.less';

class Radio extends React.Component {

    static propTypes = {
        name: React.PropTypes.string.isRequired,
        onChange: React.PropTypes.func,
        checked: React.PropTypes.bool,
        disabled: React.PropTypes.bool,
        inline: React.PropTypes.bool,
        title: React.PropTypes.oneOfType([
            React.PropTypes.string,
            React.PropTypes.node,
            React.PropTypes.element,
        ]),
        prefixCls: React.PropTypes.string,
        className: React.PropTypes.string,
        btnStyle: React.PropTypes.bool,
    };

    static defaultProps = {
        inline: false,
        disabled: false,
        checked: false,
        prefixCls: "ult",
    }

    handleChange(e) {
        const { onChange, disabled, type } = this.props;
        if (disabled) {
            return;
        }
        if (onChange) {
            const value = e.currentTarget.value;
            onChange(value);
        }        
    }

    render() {
        const {className, title, name, value, defaultChecked, checked, disabled, prefixCls, inline, btnStyle } = this.props;
        const classes = classnames(`${prefixCls}-checkbox`, className, {[`${prefixCls}-checkbox-inline`]: inline, "checked": checked, "disabled": disabled});
        if (btnStyle) {
            return (
                <label className={classnames(`${prefixCls}-btn`, {"checked": checked, "disabled": disabled})}>
                    <input type="radio" checked={checked} name={name} value={value} onChange={this.handleChange.bind(this)} disabled={disabled} />
                    {title}
                </label>
            )
        }
        return (
            <label className={classes}>
                <span className={`${prefixCls}-checkbox-inner ${prefixCls}-radio-type`} ></span>
                <input type="radio" checked={checked} name={name} value={value} onChange={this.handleChange.bind(this)} disabled={disabled} />
                {title}
            </label>
        )
    }
}

export default Radio;