/*
 * @Author: SiMeiyu 
 * @Date: 2017-07-04 09:59:20 
 */ 
import classnames from 'classnames';
import Radio from './radio';
import './checkBox.less';

class RadioGroup extends React.Component {

  static propTypes = {
    items: React.PropTypes.array.isRequired,
    className: React.PropTypes.string,
    defaultValue: React.PropTypes.string,
    prefixCls: React.PropTypes.string,
    btnStyle: React.PropTypes.bool,
    inline: React.PropTypes.bool,
  }

  static defaultProps = {
    name: 'radioGroup',
    prefixCls: "ult",
    btnStyle: false,
  }

  constructor(props) {
    super(props);
    this.state = {
      checked: this.props.defaultValue || '', 
    }
  }

  handleChange(value) {
    this.setState({
      checked: value,
    });
    if(this.props.onChange) {
      this.props.onChange(value);
    }
  }

  render() {
    const {className, prefixCls, name, items, inline, btnStyle} = this.props;
    const classes = classnames({
      [`${prefixCls}-radio-group`]: !btnStyle,
      [`${prefixCls}-btn-group`]: btnStyle && inline,
      [`${prefixCls}-btn-group-vertical`]: btnStyle && !inline,
    }, className);
    return (
      <div className={classes}>
        {
          items.map((item, index) => (
            <Radio
              key={index}
              name={name}
              value={item.value}
              title={item.title}
              disabled={item.disabled || false}
              checked={this.state.checked === item.value}
              onChange={this.handleChange.bind(this)}
              inline={inline}
              btnStyle={btnStyle}
            />
          ))
        }
      </div>
    )
  }
}

export default RadioGroup;